![CI](https://github.com/ywatanabe1989/mngs/actions/workflows/pip_install.yml/badge.svg)

## Installation
``` bash
$ pip install mngs
```

## Galleries
[`mngs.dsp`](https://github.com/ywatanabe1989/mngs/tree/develop/src/mngs/dsp#readme)

## Contact
Yusuke Watanabe (ywata1989@gmail.com).

